<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');

/**
 * Classe que representa el controlador d'alumnes.
 * @author David Español Diaz
 * @versió 1.0; PHP 5.0".
 */
class Alumnes extends CI_Controller{
	
	//Definició del constructor.
	public function __construct(){
		parent::__construct();
		//Carrega llibreries i helpers.
		$this->load->library('session');
		$this->load->helper('url');
		//Si no esta connectat no es pot visualitzar la plana.
		if(!$this->session->userdata('autenticacio')){
			$this->session->set_flashdata('error', 'No has fet login.');
			redirect('login', 'refresh');
		}
		//Carrega el model Alumnes.
		$this->load->model('Alumnes_model');
		$valor1=$this->uri->segment(2);
		$valor2=$this->uri->segment(3);		
		
		//Segons el rol d'usuari podrà veure uns continguts o altres.
		$rol=$this->session->userdata('rol_usuari');
		if($rol==1){
			//Redirecciona si es l'administrador.
			redirect('inici/admin', 'refresh');	
		}
	}
	
	/**
     * Métode per carregar l'inici de la pàgina.
	 * Recull les dades a mostrar a la vista.
     */
	public function index(){
	
		//Carrega llibreries i helpers i dades de sessió.
		$this->load->helper('inicial');	
		$id_convocatoria=$this->session->userdata('convocatoria_actual');
		
		//En funció de si hi ha convocatoria oberta o no fa les gestions.
		if (empty($id_convocatoria)){
			//Carrega la vista informativa de cap convocatoria oberta.
			$this->load->view('blank');	
		} else{	
			//Crear objecte Alumne e insercio en un array si hi ha alumnes.
			$dada['lstalumnes']=$this->Alumnes_model->llistat_alumnes($id_convocatoria);
			if($dada == -1){
				$dada['lstalumnes']='';
			}
			//Es carrega la vista.
			$this->load->view('alumnes_view', $dada);
		}
	}
		
	/**
     * Mètode per modificar un alumne.
     * {pre: Hi ha dades al formulari rebut}.
     * {post: es modifica l'alumne cridant al model}.
     * Retorna missatges d'error si el formulari no es correcte.}
     */
	public function modificar_alumne($id_alumne){
		
		//Carrega llibreries i helpers.
		$this->load->helper(array('url','form'));
		$this->load->library('form_validation');
		
		//Crear objecte Alumne e insercio en un array.
		$id_convocatoria=$this->session->userdata('convocatoria_actual');
		$obj_conv=new Alumnes_model($id_alumne,$id_convocatoria,'');	
		$dada['lstalumne']=$obj_conv->veureAlumne();
		
		//Si les dades del formulari són correctes les recull. Si no visualitza de nou el formulari.
		if($this->form_validation->run('alumne')==FALSE){		
			$this->load->view('modificar_alumne_view',$dada);
		} else{
			//Recull les dades del formulari.
			$id_alumne = $this->input->post("id_alumne");
			$id_convocatoria = $this->input->post("id_convocatoria");
			$mail = $this->input->post("correu");
			
			//Crear objecte Alumne
			$obj_alum=new Alumnes_model($id_alumne,$id_convocatoria,$mail);
			$obj_alum->modificarAlumne();	
				
			//Es carrega la vista de confirmació.		
			$dada['enllaç']='alumnes';
			$this->load->view('formulari_validat',$dada);					
		}		
	}  
}
?>