<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
 /**
 * Classe que representa el controlador de convocatoria
 * @author David Español Diaz
 * @versió 1.0; PHP 5.0".
 */
class Convocatories extends CI_Controller{
	
	//Definició del constructor.
	public function __construct(){
	
		parent::__construct();
		//Carrega llibreries i helpers.
		$this->load->library('session');
		$this->load->helper('url');
		//Si no esta connectat no es pot visualitzar la plana.
		if(!$this->session->userdata('autenticacio')){
			$this->session->set_flashdata('error', 'No has fet login.');
			redirect('login', 'refresh');
		}
		//Carrega el model Convocatòries.
		$this->load->model('Convocatories_model');	
		$id_convocatoria=$this->uri->segment(3);
		//Segons el rol d'usuari podrà veure uns continguts o altres.
		$rol=$this->session->userdata('rol_usuari');
		if($rol==1){
			//Redirecciona si es l'administrador.
			redirect('inici/admin', 'refresh');	
		}
	}
	
	
	/**
     * Mètode per carregar l'inici de la pàgina.
	 * Recull les dades a mostrar a la vista.
     */
	public function index(){
	
		//Carrega el llistat de convocatòries d'un tutor i accedeix a les dades de sessió.
		$id_tutor = $this->session->userdata('id_usuari');
		$dada['lstconvocatories']=$this->Convocatories_model->llistat_convocatories($id_tutor);
		
		//No hi ha convocatories.
		if($dada == -1){
			$dada['lstconvocatories']='';
		}

		//Carrega la vista.
		$this->load->view('convocatories_view', $dada);
	}
	
	/**
     * Mètode per inserir una nova convocatòria.
     * {pre: Hi ha dades al formulari rebut}
     * {post: Es crea una nova convocatòria cridant al model}
     * Retorna missatges d'error si el formulari no és correcte.
     */
	public function nova_convocatoria(){
	
		//Carrega llibreries i helpers.
		$this->load->helper('form');
		$this->load->library('form_validation');
		
		//Si les dades del formulari són correctes les recull. Si no, visualitza de nou el formulari.
		//Per mitjà de form_validation al directori /config comprova el formulari.
		if($this->form_validation->run('convocatoria')==FALSE){
			$this->load->view('nova_convocatoria_view');
		} else{
			//Comprova que les dates estiguin bé.
			$data_inici = $this->input->post("data_inici");
			$data_fi = $this->input->post("data_fi");
			//Comprova que la data inici sigui menor que fi. 
			if($data_fi <= $data_inici){
				$this->session->set_flashdata('error', 'La data de fi es menor o igual que inici.');
				redirect('convocatories/nova_convocatoria', 'refresh');	
			} else{	
				
				//Conversió de dades DD/MM/YY a YY/MM/DD.
				$data_inici = $this->input->post("data_inici");
				$data_fi = $this->input->post("data_fi");
				$date_begin=explode('-',$data_inici);
				$data_inici_convocatoria = $date_begin[2].'-'.$date_begin[1].'-'.$date_begin[0];
				$date_end=explode('-',$data_fi);
				$data_fi_convocatoria = $date_end[2].'-'.$date_end[1].'-'.$date_end[0];
				
				//Recull les dades de sessió.
				$id_tutor = $this->session->userdata('id_usuari');
				$id_convocatoria = $this->input->post("id_convocatoria");
				$nom_convocatoria = $this->input->post("nom_convocatoria");
				
				//Crear objecte Convocatoria				
				$obj_conv=new Convocatories_model($id_convocatoria,$nom_convocatoria,$data_inici_convocatoria,$data_fi_convocatoria,$id_tutor);
				
				$avui=date("Y-m-d");
						if($data_inici_convocatoria<= $avui && $data_fi_convocatoria>= $avui){
							$this->session->set_userdata('convocatoria_actual', $id_convocatoria);
						}
				
				//Es verifica que la convocatoria no existeix			
				if(!$obj_conv->existeixConvocatoria())
				{	//Es verifica que les dates no es solapen a altres ja existents.		
					if($obj_conv->comprovarDates() != -1)
					{
						if($obj_conv->novaConvocatoria()) {
							$this->Convocatories_model->setEstatConvocatoria($id_convocatoria,'0');
						} else{
							$this->session->set_flashdata('error', 'Hi ha hagut problemes al guardar.');
						}
						//Si la convocatòria està oberta es guarda a la sessió.
						$avui=date("Y/m/d");
						if($data_inici<= $avui && $data_fi>= $avui){
							$this->session->set_userdata('convocatoria_actual', $id_convocatoria);
						}
						//Es carrega la vista de confirmació.
						$dada['enllaç']='convocatories';
						$this->load->view('formulari_validat',$dada);
					}
					else {
						//Si hi ha dates solapades.
						$this->session->set_flashdata('error', 'Les dates es solapen.');
						redirect('convocatories/nova_convocatoria', 'refresh');					
					}
				} else{		
					$this->session->set_flashdata('error', 'Aquesta convocatoria ja existeix.');
					redirect('convocatories/nova_convocatoria', 'refresh');	
				}
			}		
		}		
	}
	
	/**
     * Mètode per modificar una convocatòria.
     * {pre: Hi ha dades al formulari rebut}
     * {post: Es modifica la convocatòria cridant al model}
     * Retorna missatges d'error si el formulari no és correcte.
     */
	public function modificar_convocatoria($id_convocatoria){
	
		//Carrega llibreries i helpers.
		$this->load->helper(array('form','date'));
		$this->load->library('form_validation');

		if($this->input->post("data_inici")&& $this->input->post("data_fi")){
		
			$data_inici = $this->input->post("data_inici");
			$data_fi = $this->input->post("data_fi");
			//Conversió de dades DD/MM/YY a YY/MM/DD.
			$date_begin=explode('-',$data_inici);
			$data_inici_convocatoria = $date_begin[2].'-'.$date_begin[1].'-'.$date_begin[0];
			$date_end=explode('-',$data_fi);
			$data_fi_convocatoria = $date_end[2].'-'.$date_end[1].'-'.$date_end[0];
			//Es pasa la data a valor UNIX per fer la comparació.
			$data_inici_unix=strtotime($data_inici_convocatoria);
			$data_fi_unix=strtotime($data_fi_convocatoria);
		}
		
		//Crear objecte Convocatoria e insercio en un array.
		$obj_conv=new Convocatories_model($id_convocatoria);	
		$dada['lstconvocatoria']=$obj_conv->existeixConvocatoria();
		
		//Si les dades del formulari són correctes les recull. Sino visualitza de nou el formulari.
		//Per mitjà de form_validation al directori /config, comprova el formulari.
		if($this->form_validation->run('convocatoria')==FALSE){
			$this->load->view('modificar_convocatoria_view',$dada);
		} else{
			//Comprova que la data inici sigui menor que fi. 
			if(isset($data_fi_unix,$data_inici_unix)){
				if($data_fi_unix <= $data_inici_unix){
					$this->session->set_flashdata('error', 'La data de fi es menor o igual que inici.');
					redirect('convocatories/modificar_convocatoria/'.$id_convocatoria, 'refresh');	
				}
			}
			//Recull les dades del formulari.
			$id_nova_convocatoria = $this->input->post("id_convocatoria");
			$nom_convocatoria = $this->input->post("nom_convocatoria");
			$id_tutor = $this->session->userdata('id_usuari');
	
			//Crear objecte Convocatoria
			$obj_conv=new Convocatories_model($id_nova_convocatoria,$nom_convocatoria,$data_inici_convocatoria,$data_fi_convocatoria,$id_tutor);
			
			//Es verifica que les dates no es solapen a altres ja existents.		
				if($obj_conv->comprovarDates() != -1) {
					$obj_conv->modificarConvocatoria();
					
					//Si la convocatòria està oberta es guarda a la sessió.
					$avui=date("Y-m-d");
					if($data_inici_convocatoria<= $avui && $data_fi_convocatoria>= $avui){
						$this->session->set_userdata('convocatoria_actual', $id_convocatoria);
					}
					else{
						$this->session->set_userdata('convocatoria_actual', '');
					}
					//Es carrega la vista de confirmació.
					$dada['enllaç']='convocatories';
					$this->load->view('formulari_validat',$dada);
				} else {
					//Dates solapades
					$this->session->set_flashdata('error', 'Les dates es solapen.');
					redirect('convocatories/modificar_convocatoria/'.$id_convocatoria, 'refresh');				
				}
		}		
	}
	
	/**
     * Mètode per esborrar una convocatòria.
     * {pre: Hi ha una convocatòria a esborrar}.
     * {post: la convocatòria s'ha esborrat cridant al model}.
     */	
	public function esborrar_convocatoria($id_convocatoria){
	
		//Crear objecte Convocatoria
		$obj_conv=new Convocatories_model($id_convocatoria);
		$obj_conv->esborrarConvocatoria();
		//Es torna a la plana del llistat de convocatories.
		redirect('convocatories', 'refresh');		
	}
	
	/**
     * Mètode per assignar alumnes a una convocatòria.
     * {pre: Hi ha una convocatòria a assignar}.
     * {post: Els alumnes s'han insertat cridant al model}.
     */		
	public function assignar_alumnes($id_convocatoria){
		
		//Carrega llibreries i helpers.
		$this->load->helper(array('form'));
		$this->load->library('form_validation');
		
		//Si les dades del formulari sòn correctes les recull. Si no visualitza de nou el formulari.
		//Per mitjà de form_validation al directori /config comprova el formulari.	
		if($this->form_validation->run('excel')==FALSE){		
			$this->load->view('associacio_convocatoria_view',$id_convocatoria);
		} else{
			//Si hi ha arxiu.
			if($_FILES['xls']['name'] != null){
				//Si ja hi ha alumnes donats d'alta dona un missatge. En cas contrari fa l'associació.
				if ($this->Convocatories_model->verificarAlumnes($id_convocatoria)==-1){
					$this->session->set_flashdata('error', 'Ja hi ha alumnes associats.');
					redirect('convocatories');
				} else{
					//Recull les dades del formulari.
					$id_convocatoria = $this->input->post("id_convocatoria");
					$name     = $_FILES['xls']['name'];
					$tname    = $_FILES['xls']['tmp_name'];
					
					
					if($this->Convocatories_model->associarAlumnesConvocatoria($tname,$id_convocatoria)!=-1)
					{
						$this->Convocatories_model->setEstatConvocatoria($id_convocatoria,'1');
						//Es carrega la vista de confirmaciò.
						$dada['enllaç']='convocatories';
						$this->load->view('formulari_validat',$dada);
					} else{
						$this->session->set_flashdata('error', 'El llistat excel no es correcte');
						redirect('convocatories');
					}
				}
			} else {
				//Si no hi ha arxiu.
				$this->session->set_flashdata('error', 'No hi ha arxiu.');
				redirect('convocatories/assignar_alumnes/'.$id_convocatoria);
			}
		}
	}
	/**
     * Mètode per esborrar alumnes d'una convocatòria.
     * {pre: Hi ha una convocatòria a gestionar}.
     * {post: Els alumnes de la convocatòria s'han esborrat cridant al model}.
     */		
	public function esborrarAlumnes($id_convocatoria){
		
		//Crear objecte Convocatoria
		$obj_conv=new Convocatories_model($id_convocatoria);
		$obj_conv->esborrarAlumnesConvocatoria();
		//Es torna a la plana del llistat de convocatories.
		redirect('convocatories', 'refresh');
	}
}
?>