<?php if (! defined('BASEPATH')) exit('No direct script access allowed');
 /**
 * Classe que representa el controlador de login.
 * @author David Español Diaz
 * @versió 1.0; PHP 5.0".
 */
class Login extends CI_Controller{
	//Definició del constructor.
	public function __construct(){
		parent::__construct();
		//Carrega llibreries i helpers.
		
		$this->load->model('Login_model');
		$this->load->helper(array('url', 'form'));
		$this->load->library(array('session','form_validation'));
	}
	
	/**
     * Mètode per carregar l'inici de la pàgina.
	 * Comprova si existeix la sessio d'usuari.
	 * Carrega la plana de login o d'inici en funcio de si està connectat.
     */
	public function index() {
		// Si existeix carrega la vista d'inici. En cas contrari torna a login.
		if (!$this->session->userdata('id_usuari')){
			$this->load->view('login_view');	
		} else {			
			$this->load->view('inici_view');
		}
	}
	
	/**
     * Mètode per autenticar a l'usuari.
     * {pre: Hi ha dades al formulari rebut}.
     * {post: Es crea una connexió cridant al model}.
     * Retorna missatges d'error si el formulari no es correcte.}
     */
	public function autenticar() {
				
		// Si les dades del formulari són correctes les recull. Si no visualitza de nou el formulari.
		//Per mitjà de form_validation al directori /config comprova el formulari.
		if($this->form_validation->run('login')==FALSE){	
			$this->load->view('login_view');
		}
		else{
			//Recull les dades del formulari.
			$id_usuari = $this->input->post("usuari");
			$password = sha1($this->input->post('password'));
			
			//Crear objecte Login
			$obj_login=new Login_model($id_usuari,$password);
			if($obj_login->autenticarUsuari()!=-1){
				//Es cerca la convocatoria actual del tutor 
				$this->load->model('Convocatories_model');
				$convocatoria_actual=$this->Convocatories_model->veureConvocatoriaActual($id_usuari);
				
				//Es cerca el rol que te l'usuari.
				$this->load->model('Usuaris_model');
				$obj_user=new Usuaris_model($id_usuari);
				$dada=$obj_user->veureUsuari();
				$rol=$dada[0]->rol;
				$nom=$dada[0]->nom_usuari;
				
				// Es crea un array amb les variables de sessio 'id_usuari'.
				$datasession = array(
					'id_usuari'  => $id_usuari,
					'autenticacio' => TRUE,
					'rol_usuari' => $rol,
					'nom_usuari' => $nom
				);
				
				//Si hi ha convocatoria actual.
				if($convocatoria_actual != -1){
					// S'agrega un element de convocatoria actual.
					$datasession['convocatoria_actual'] = $convocatoria_actual;
				} else{
					// No hi ha convocatoria actual.
					$datasession['convocatoria_actual'] = "";
				}
					
				// Es crea la sessió i es fa la redirecció cap a la plana d'inici
				$this->session->set_userdata($datasession);
				redirect('inici', 'refresh');
			}
			else {
				// Si l'usuari/password són incorrectes.
				$this->session->set_flashdata('error', 'Alguna de les dades no són correctes.');
				redirect('login', 'refresh');
			}
	    }	
	}
		
	/**
     * Métode per anar a la vista de nou password a l'usuari
     * {pre:}
     * {post: Es veu la vista}
     */ 
	public function recuperar() {
		$this->load->view('password_view');
	}
	
	/**
     * Métode per enviar password a l'usuari
     * {pre: L'usuari existeix, el mail existeix}.
     * {post: El password s'ha enviat}
     */ 
	public function enviar_password() {

		//Si les dades del formulari són correctes les recull. Si no visualitza de nou el formulari.
		//Per mitjà de form_validation al directori /config comprova el formulari.
		if($this->form_validation->run('login')==FALSE){		
			$this->load->view('password_view');
		} else{
			
			//Es recuperen les dades del formulari.
			$mail_usuari = $this->input->post("mail_usuari");
			$id_usuari = $this->input->post("id_usuari");
				
			//Crear objecte Usuari carregant el model Usuaris.
			$this->load->model('Usuaris_model');			
			$obj_user=new Usuaris_model($id_usuari);
			$data['usuari']=$obj_user->veureUsuari();
			if($data['usuari']==-1){
				$usuari_trobat=-1;
			} else{
				$usuari_trobat=1;
			}

			//Es verifica que l'usuari existeix
			if($usuari_trobat!=-1){
				
				//Es recullen les dades de la BBDD.
				$id_trobat=$data['usuari'][0]->id_usuari;
				$mail_trobat=$data['usuari'][0]->mail_usuari;
				
				if($id_trobat==$id_usuari){
					// Si el correu es el mateix
					if($mail_trobat==$mail_usuari){
						$this->load->helper('password');
						
						//Nou password creat.
						$password=get_random_password();
						
						//Recuperar dades d'administracio.
						$remitent='Admin';
						$this->load->model('Usuaris_model');
						$this->load->library('encrypt');
							
						//Agafar valors de imap de l'arxiu config.
						$protocol = $this->config->item('protocol');
						$smtp_host = $this->config->item('smtp_host');
						$smtp_port = $this->config->item('smtp_port');
						$charset = $this->config->item('charset');
						$mailtype = $this->config->item('mailtype');
									
						//Crear objecte usuari remitent=Admin.
						$obj_smtp=new Usuaris_model($remitent);
						$datasmtp['smtp']=$obj_smtp->veureSmtpUsuari();
						$id_smtp=$datasmtp['smtp'][0]->id_smtp;
						
						//Introdueix a un array les dades de gestió de recuperació.
						$password_smtp=$this->encrypt->decode($datasmtp['smtp'][0]->password_smtp);
						$config = Array(
										'protocol' => $protocol,
										'smtp_host' => $smtp_host,
										'smtp_port' => $smtp_port,
										'smtp_user' => $id_smtp,
										'smtp_pass' => $password_smtp,
										'mailtype'  => $mailtype, 
										'charset'   => $charset

									);
						//Carrega la llibreria i fa les gestions.
						$this->load->library('email', $config);
						$this->email->from('Admin vTutories', 'Admin vTutories');
						$this->email->to($mail_usuari);
						$this->email->subject('Recuperacio password');
						$this->email->message('El teu nou password es: '.$password); 
						$this->email->set_newline("\r\n");	
						$this->email->send();
						
						//Set del nou password a la BBDD.
						$this->Login_model->nouPassword($password,$id_usuari);
						
						//Es carrega la vista de confirmació.
						$this->session->set_flashdata('error', 'Contrasenya enviada. Connecta amb el teu gestor..');
						redirect('login', 'refresh');	
					} else{
						//El mail no coincideix.
						$this->session->set_flashdata('error', 'Mail no coincident.');
						redirect('login/recuperar', 'refresh');
					
					}
				} else{
						//Dades no coincidents
						$this->session->set_flashdata('error', 'Dades no coincidents.');
						redirect('login/recuperar', 'refresh');	
				}
			} else{
				//L'usuari no existeix.
				$this->session->set_flashdata('error', 'Usuari inexistent.');
				redirect('login/recuperar', 'refresh');
			}
		}
	}
	
	/**
     * Mètode per terminar la sessió.
     * {pre: Hi ha una sessió oberta}.
     * {post: Es tanca la sessió}
     */
	public function logout() {
	
	    // Es recullen les dades de sessió actuals
		$datasession = array(
				  'id_usuari'  => NULL,
				  'autenticacio' => FALSE,
				  'convocatoria_actual' => NULL
				);
				
	    // S'elimina la sessió.
	    $this->session->unset_userdata($datasession);
		
	    // Es fa la redirecció cap a la plana de login.
		$this->session->set_flashdata('error', 'La sessió ha estat tancada.');
	    redirect('login', 'refresh');
	}

}
?>