<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
 /**
 * Classe que representa el controlador de missatges.
 * @author David Español Diaz
 * @versió 1.0; PHP 5.0".
 */
class Missatges extends CI_Controller{
	
	//Definició del constructor.
	public function __construct(){
	
		parent::__construct();
		//Carrega llibreries i helpers.
		$this->load->helper('url');	
		$this->load->library(array('Imap','session'));

		//Si no esta connectat no es pot visualitzar la plana.
		if(!$this->session->userdata('autenticacio')){
			$this->session->set_flashdata('error', 'No has fet login.');
			redirect('login', 'refresh');
		}
		//Recupera dades de sessió.
		$id_tutor = $this->session->userdata('id_usuari');
		$id_convocatoria = $this->session->userdata('convocatoria_actual');
		
		//Segons el rol d'usuari podrà veure uns continguts o altres.
		$rol=$this->session->userdata('rol_usuari');
		if($rol==1){
			//Redirecciona si es l'administrador.
			redirect('inici/admin', 'refresh');	
		}
	}
	
	/**
     * Mètode per carregar la pàgina de missatges.
	 * Recull les dades a mostrar a la vista.
     */
	public function index(){
			
		//Carrega llibreries i helpers.
		$this->load->library('encrypt');
		
		//Comprova la carpeta a mostrar. Per defecte es INBOX.
		if($this->uri->segment(3)){
			$carpeta=$this->uri->segment(3);
		} else{ $carpeta='INBOX';
			redirect('missatges/index/'.$carpeta, 'refresh');
		}
			
		//Recuperar dades del tutor mitjançant la sessió.
		$id_tutor = $this->session->userdata('id_usuari');
			
		//Agafar valors de smtp de l'arxiu config.
		$imap_server = $this->config->item('imap_server');
					
		//Crear objecte usuari carregant el model Usuaris.
		$this->load->model('Usuaris_model');
		$obj_smtp=new Usuaris_model($id_tutor);
		
		//Comprovar si usuari te posades dades SMTP/IMAP.
		if($obj_smtp->veureSmtpUsuari()!=-1){
			$datasmtp['smtp']=$obj_smtp->veureSmtpUsuari();
			$id_smtp=$datasmtp['smtp'][0]->id_smtp;
			$password_smtp=$this->encrypt->decode($datasmtp['smtp'][0]->password_smtp);

			//Connexió amb el seu compte de correu.
			if($this->imap->connect($id_smtp,$password_smtp,$imap_server,$carpeta)==TRUE){					
				$total_miss=$this->imap->msg_count();
				$page=$this->uri->segment(4);
					
				//Carrega la llibreria paginacio.
				$this->load->library('paginacio');
				$dada=$this->paginacio->paginacio($total_miss,$page);

				//Desconnexio de la connexio.
				$this->imap->close();
					
				//Carrega la vista.
				$this->load->view('missatges_view',$dada);
			} else{
				//Carrega la vista.
				$this->load->view('informacio_view');
			}
		} else{
			//Redirecció a inici.
			$this->session->set_flashdata('error', 'Error: No has posat dades de connexió al teu gestor de correu.');
			redirect('inici', 'refresh');
		}					
	}  
	
	/**
     * Mètode per veure un missatge.
     * {pre: Hi ha un missatge seleccionat}
     * {post: Es visualitza el missatge}
     */
	public function veure_missatge($carpeta,$id_missatge){
		
		//Recuperar dades del tutor mitjançant dades de sessió.
		$id_tutor = $this->session->userdata('id_usuari');
		//Carrega llibreries i helpers.
		$this->load->model('Usuaris_model');
		$this->load->library('encrypt');
			
		//Agafar valors de imap de l'arxiu config.
		$imap_server = $this->config->item('imap_server');
					
		//Crear objecte usuari.
		$obj_smtp=new Usuaris_model($id_tutor);
		$datasmtp['smtp']=$obj_smtp->veureSmtpUsuari();
		$id_smtp=$datasmtp['smtp'][0]->id_smtp;
		$password_smtp=$this->encrypt->decode($datasmtp['smtp'][0]->password_smtp);

		//Connexió amb el compte de correu.
		if($this->imap->connect($id_smtp,$password_smtp,$imap_server,$carpeta)==TRUE){
			$dada['missatge']=$this->imap->veureMissatge($id_missatge);
			$this->imap->close();
		}
		//Carrega la vista.
		$this->load->view('mail_view',$dada);
	}
	
	/**
     * Mètode per respondre un missatge.
     * {pre: Hi ha un missatge seleccionat}
     * {post: Es respon el missatge}
     */
	public function respondre(){
		
		//Carrega llibreries i helpers.
		$this->load->helper('form');
		$this->load->library(array('form_validation','encrypt'));
		
		//Comprova les dades de formulari.
		$this->form_validation->set_rules('resposta','resposta','required');
		//Si les dades del formulari són correctes les recull. Si no, visualitza de nou el formulari.
		if($this->form_validation->run()==FALSE){	
			$this->load->view('missatges_view');
		} else{
			//Recull les dades del formulari.
			$cos_missatge = $this->input->post("resposta");
			
			//Agafar valors de smtp de l'arxiu config. 
			$protocol = $this->config->item('protocol');
			$smtp_host = $this->config->item('smtp_host');
			$smtp_port = $this->config->item('smtp_port');
			$charset = $this->config->item('charset');
			$mailtype = $this->config->item('mailtype');
					
			//Recupera dades d'usuari.
			$id_tutor = $this->session->userdata('id_usuari');
			
			//Recuperar valors personals de smtp de l'usuari				
			//Crear objecte usuari.
			$this->load->model('Usuaris_model');
			$obj_smtp=new Usuaris_model($id_tutor);
			$datasmtp['smtp']=$obj_smtp->veureSmtpUsuari();
			$id_smtp=$datasmtp['smtp'][0]->id_smtp;
			$password_smtp=$this->encrypt->decode($datasmtp['smtp'][0]->password_smtp);
			
			//Dades d'accés al compte de correu.
			$config = Array(
				'protocol' => $protocol,
				'smtp_host' => $smtp_host,
				'smtp_port' => $smtp_port,
				'smtp_user' => $id_smtp,
				'smtp_pass' => $password_smtp,
				'mailtype'  => $mailtype, 
				'charset'   => $charset

			);
			
			$obj_user=new Usuaris_model($id_tutor);				
			$datauser['usuari']=$obj_user->veureUsuari();
			//Mail i nom del tutor
			$mail_tutor=$datauser['usuari'][0]->mail_usuari;
			$nom_tutor=$datauser['usuari'][0]->nom_usuari;
			
			
			//Destinatari i creació de mail.
			$mail_alumne=$this->uri->segment(3);
			$assumpte=$this->uri->segment(4);
			$real_id=$this->uri->segment(5);			
			//Procés d'enviament.
			$this->load->library('email', $config);
			$this->email->from($mail_tutor, $nom_tutor);
			
			$this->email->to($mail_alumne,''); 
			$this->email->subject($assumpte);
			$this->email->message($cos_missatge); 
			$this->email->set_newline("\r\n");

			//Envia el missatge i redirecciona.
			//$this->email->send();
			//Carrega el model Missatges/Alumnes.
			$this->load->model('Missatges_model');	
			$this->load->model('Alumnes_model');

			//Gravar flag resposta.
			$this->Missatges_model->gravarResposta($real_id);
			//Gravar estat feedback.
			$id_convocatoria=$this->session->userdata('convocatoria_actual');
			$id_alumne=$this->Alumnes_model->veureId($mail_alumne);
			$this->Alumnes_model->setEstatAlumne($id_alumne,$id_convocatoria,11);
			redirect('missatges', 'refresh');
			
		}
	}
	
	/**
     * Mètode per crear un missatge nou.
     * {pre: Hi ha destinataris seleccionats.
     * {post: Es crea el nou missatge el missatge}
     */
	public function nou_missatge(){
		
		//Carrega llibreries i helpers.
		$this->load->helper('form');
		$this->load->library(array('form_validation','encrypt'));

		//Dades que s'han de mantenir en tots els casos.
		$destinataris= $this->input->post("destinataris");
		$alumnes= $this->input->post("alumnes");
		$dada['alumne']= explode(",", $destinataris);
		
		//Si les dades del formulari són correctes les recull. Si no, visualitza de nou el formulari.
		//Per mitjà de form_validation al directori /config comprova el formulari.
		if($this->form_validation->run('missatges')==FALSE){
			$this->session->set_flashdata('error', 'Hi falten dades.');	
			redirect('seguiment','refresh');
		} else{
		
			//Recull les dades del formulari.
			$cos_missatge = $this->input->post("cos");
			$assumpte_missatge = $this->input->post("assumpte");
			
			//Agafar valors de smtp de l'arxiu config. 
			$protocol = $this->config->item('protocol');
			$smtp_host = $this->config->item('smtp_host');
			$smtp_port = $this->config->item('smtp_port');
			$charset = $this->config->item('charset');
			$mailtype = $this->config->item('mailtype');
					
			//Recull dades d'usuari.
			$this->load->model('Usuaris_model');
			$id_tutor = $this->session->userdata('id_usuari');
			
			//Recuperar valors personals de smtp de l'usuari.				
			//Crear objecte usuari.
			$obj_smtp=new Usuaris_model($id_tutor);
			$datasmtp['smtp']=$obj_smtp->veureSmtpUsuari();
			$id_smtp=$datasmtp['smtp'][0]->id_smtp;
			$password_smtp=$this->encrypt->decode($datasmtp['smtp'][0]->password_smtp);
			
			//Dades d'accés al compte de correu.			
			$config = Array(
				'protocol' => $protocol,
				'smtp_host' => $smtp_host,
				'smtp_port' => $smtp_port,
				'smtp_user' => $id_smtp,
				'smtp_pass' => $password_smtp,
				'mailtype'  => $mailtype, 
				'charset'   => $charset

			);
					
			$obj_user=new Usuaris_model($id_tutor);				
			$datauser['usuari']=$obj_user->veureUsuari();
			
			//Dades del tutor
			$mail_tutor=$datauser['usuari'][0]->mail_usuari;
			$nom_tutor=$datauser['usuari'][0]->nom_usuari;
			
			//Llibreria email.
			$this->load->library('email', $config);
			$this->email->from($mail_tutor, $nom_tutor);
			$this->email->bcc($destinataris); 
			$this->email->subject($assumpte_missatge);
			$this->email->message($cos_missatge); 
			$this->email->set_newline("\r\n");

			//Si hi han hagut problemes al enviar.				
			if (!$this->email->send()){
				$this->session->set_flashdata('error', 'Hi han hagut problemes al enviar');
			} else{
				//Inserta nou status en status alumne
				$this->load->model('Alumnes_model');
				//echo $alumnes;
				$dada['alumnes']= explode(" ", $alumnes);
				//print_r($dada['alumnes']);
				
				//Recull en un array les dades a fer el set de l'estat.
				foreach($dada['alumnes'] as $alumne){
							
					if(!empty($alumne)){
						//Crear objecte Alumne e insercio en un array.
						$id_convocatoria=$this->session->userdata('convocatoria_actual');
						$obj_conv=new Alumnes_model($alumne,$id_convocatoria);
						$dada['alumne']=$obj_conv->veureAlumne();
						//Dades de l'alumne.
						$id_alumne=$dada['alumne'][0]->id_alumne;
						//Posar un nou estat a la BBDD.Estat 10.
						$this->Alumnes_model->setEstatAlumne($id_alumne,$id_convocatoria,'10');		
					}
				}				
			}
			//Redirecció a la plana de seguiment.
			redirect('seguiment');
		}
	}
	
	/**
     * Mètode per esborrar un missatge.
     * {pre: Hi ha missatges seleccionats}
     * {post: S'han esborrat els missatges}
     */
	public function esborrar(){
		
		$carpeta=$this->uri->segment(3);
		//Recull les dades del formulari.
		$eleccio = $this->input->post("seleccio");
		
		//Recuperar dades del tutor.
		$id_tutor = $this->session->userdata('id_usuari');
		$this->load->model('Usuaris_model');
		$this->load->library('encrypt');
			
		//Agafar valors de imap de l'arxiu config.
		$imap_server = $this->config->item('imap_server');
					
		//Crear objecte usuari.
		$obj_smtp=new Usuaris_model($id_tutor);
		$datasmtp['smtp']=$obj_smtp->veureSmtpUsuari();
		$id_smtp=$datasmtp['smtp'][0]->id_smtp;
		$password_smtp=$this->encrypt->decode($datasmtp['smtp'][0]->password_smtp);
		
		//Connexió al compte de correu.
		if($this->imap->connect($id_smtp,$password_smtp,$imap_server,$carpeta)==TRUE){
			$mensaje=$this->imap->delete($eleccio,TRUE);
			$missatge=$this->imap->close();
		}
		//Redirecció a la plana de missatges.
		redirect('missatges/index/');	
	}	

}
?>