<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Classe que representa el controlador de seguiment.
 * @author David Español Diaz
 * @versió 1.0; PHP 5.0".
 */
class Seguiment extends CI_Controller{
	
	//Definició del constructor.
	public function __construct(){
	
		parent::__construct();
		//Carrega llibreries i helpers.
		$this->load->library('session');
		$this->load->helper('url');
		//Si no esta connectat no es pot visualitzar la plana.
		if(!$this->session->userdata('autenticacio')){
			$this->session->set_flashdata('error', 'No has fet login.');
			redirect('login', 'refresh');
		}
		//Carrega el model Convocatòries.
		$this->load->model('Convocatories_model');
		$this->load->model('Seguiment_model');
		$this->load->model('Inici_model');
		//Recupera dades de sessió.
		$id_convocatoria=$this->session->userdata('convocatoria_actual');
		$id_tutor = $this->session->userdata('id_usuari');
		
		//Segons el rol d'usuari podrà veure uns continguts o altres.
		$rol=$this->session->userdata('rol_usuari');
		if($rol==1){
			//Redirecciona si es l'administrador.
			redirect('inici/admin', 'refresh');	
		}
	}
	
	/**
     * Métode per carregar l'inici de la pàgina.
	 * Recull les dades a mostrar a la vista.
     */
	public function index(){
		
		//Carrega llibreries, models i helpers.
		$this->load->helper('inicial');	
		$this->load->model('Alumnes_model');
		$this->load->model('Seguiment_model');
		
		//Carrega dades de sessió.
		$id_convocatoria=$this->session->userdata('convocatoria_actual');
		$id_tutor = $this->session->userdata('id_usuari');
		
		//Comprova quin es el darrer estat convocatòria.
		$dada['actconv'][0]->status=$this->Convocatories_model->darrerEstatConvocatoria($id_convocatoria);
		
		if (empty($id_convocatoria)){
			//Carrega la vista informativa de cap convocatoria oberta.
			$this->load->view('blank');
		} else{
			
			//Crear objecte usuari carregant el model Usuaris.
			$this->load->model('Usuaris_model');
			$obj_smtp=new Usuaris_model($id_tutor);
			
			//Comprovar si usuari te posades dades SMTP/IMAP.
			if($obj_smtp->veureSmtpUsuari()!=-1){
				$datasmtp['smtp']=$obj_smtp->veureSmtpUsuari();
				$id_smtp=$datasmtp['smtp'][0]->id_smtp;
				$this->load->library('encrypt');
				$password_smtp=$this->encrypt->decode($datasmtp['smtp'][0]->password_smtp);
			
				//Crear objecte Seguiment
				$obj_seg=new Seguiment_model($id_convocatoria);
				$dada['lstalumnes']=$obj_seg->llistatAlumnesSeguiment();
				//Carrega la vista.
				$this->load->view('seguiment_view', $dada);
			} else{
			//Redirecció a inici.
			$this->session->set_flashdata('error', 'Error: No has posat dades de connexió al teu gestor de correu.');
			redirect('inici', 'refresh');
			}
		}		
	}
	 	
	/**
     * Mètode per cercar la llista d'estats d'un alumne.
     * {pre: Hi ha un parametre amb l'id de l'alumne}.
     * {post: Es retorna el llistat}.
     * Retorna missatges d'error si el formulari no es correcte.}
     */	
	public function estats_alumne($id_alumne){
		
		//Carrega model i dades de sessió.
		$this->load->model('Alumnes_model');
		$id_convocatoria=$this->session->userdata('convocatoria_actual');
		
		//Extreu el llistat d'estats alumne mitjançant el model.
		$dada['lstestats']=$this->Alumnes_model->llistatEstatsAlumnes($id_alumne,$id_convocatoria);
		//Carrega la vista.
		$this->load->view('estats_view', $dada);
	}
	
	/**
     * Mètode per fer els enviaments i les gestions del seguiment de l'alumne.
     * {pre: Hi ha dades al formulari rebut}.
     * {post: Es fa l'enviament}.
     * Retorna missatges d'error si el formulari no es correcte.}
     */
	public function enviaments(){
	
		//Carrega llibreries i helpers i dades sessió.
		$this->load->model('Seguiment_model');
		$this->load->helper(array('url','form','date'));
		$this->load->library(array('form_validation','encrypt'));
		$id_convocatoria=$this->session->userdata('convocatoria_actual');
		$nom_tutor=$this->session->userdata('nom_usuari');
		
		//Si les dades del formulari són correctes les recull. Si no, visualitza de nou el formulari.
		//Per mitjà de form_validation al directori /config comprova el formulari.
		if($this->form_validation->run('seguiment')==FALSE){
			
			$this->session->set_flashdata('error', 'Falten dades.');
			redirect('seguiment/index','refresh');
		} else{
			
			//Recull les dades del formulari.
			$eleccio = $this->input->post("eleccio");
			$seleccio= $this->input->post("seleccio");
			//Variable que permet diferents redireccions en funcio de si es un nou mail.
			$redirect=1;
			
			//Llistat d'eleccions del tutor.
			switch ($eleccio) {
				//Eleccio de benvinguda retornada.
				case 3:
					foreach($seleccio as $fila){
						$this->load->model('Alumnes_model');
						$this->Alumnes_model->setEstatAlumne($fila,$id_convocatoria,$eleccio);
					}				
					break;
				//Eleccio d'alumne donat de baixa.			
				case 4:
					foreach($this->input->post("seleccio") as $fila){
						$this->load->model('Alumnes_model');
						$this->Alumnes_model->setEstatAlumne($fila,$id_convocatoria,$eleccio);
					}				
					break;
				//Eleccio de nou mail.		
				case 10:
					$i=0;
					foreach($seleccio as $alumne){							

						//Crear objecte Alumne
						$this->load->model('Alumnes_model');
						$obj_alum=new Alumnes_model($alumne,$id_convocatoria);
						$alumne=$obj_alum->veureAlumne();
	
						$dada['lstalumne'][$i]->mail=$alumne[0]->mail;;
						$dada['lstalumne'][$i]->id_alumne=$alumne[0]->id_alumne;;
						$i++;
					}
					
					//Es carrega la vista.
					$redirect='0';
					$this->load->view('nou_mail_view', $dada);
					break;
				//Eleccio de missatge tipus plantilla.										
				default: {
					
					//Carrega els models.
					$this->load->model('Convocatories_model');
					$this->load->model('Alumnes_model');
					
					//Crear objecte Convocatoria							
					$obj_conv=new Convocatories_model($id_convocatoria);
					$dada['lstconvocatoria']=$obj_conv->getConvocatoria();;			
					$nom_convocatoria=$dada['lstconvocatoria'][0]->nom_convocatoria;
					$data_inici=$dada['lstconvocatoria'][0]->data_inici;
					$data_fi=$dada['lstconvocatoria'][0]->data_fi;
					
					//Recuperació de plantilla a enviar.
					$missatge=$this->Seguiment_model->getPlantillaAEnviar($eleccio,$id_convocatoria,$nom_convocatoria,$data_inici,$data_fi,$nom_tutor);
					
					//Agafar valors de smtp de l'arxiu config. 
					$protocol = $this->config->item('protocol');
					$smtp_host = $this->config->item('smtp_host');
					$smtp_port = $this->config->item('smtp_port');
					$charset = $this->config->item('charset');
					$mailtype = $this->config->item('mailtype');
					
					//Dades d'usuari.
					$this->load->model('Usuaris_model');
					$id_tutor = $this->session->userdata('id_usuari');
					
					//Recuperar valors personals de smtp de l'usuari.				
					//Crear objecte usuari.
					$obj_smtp=new Usuaris_model($id_tutor,'','');
					$datasmtp['smtp']=$obj_smtp->veureSmtpUsuari();
					$id_smtp=$datasmtp['smtp'][0]->id_smtp;
					$password_smtp=$this->encrypt->decode($datasmtp['smtp'][0]->password_smtp);
					
					//Donar valors a enviament SMTP
					$config = Array(
						'protocol' => $protocol,
						'smtp_host' => $smtp_host,
						'smtp_port' => $smtp_port,
						'smtp_user' => $id_smtp,
						'smtp_pass' => $password_smtp,
						'mailtype'  => $mailtype, 
						'charset'   => $charset

					);
					
					//Es crea un objecte Usuari.
					$obj_user=new Usuaris_model($id_tutor);				
					$datauser['usuari']=$obj_user->veureUsuari();
					
					//Agafem les dades de mail d'usuari i nom.
					$mail_tutor=$datauser['usuari'][0]->mail_usuari;
					$nom_tutor=$datauser['usuari'][0]->nom_usuari;

					//Recull els id dels alumnes per tal d'enviar emails
					foreach($seleccio as $fila){							

						//Dades del correu											
						$motiu="Informacio curs: ".$nom_convocatoria;
									
						//Mail de l'alumne
						//Crear objecte Alumne
						$obj_alum=new Alumnes_model($fila,$id_convocatoria);
						$dada['lstalumne']=$obj_alum->veureAlumne();
						$mail_alumne=$dada['lstalumne'][0]->mail;
						$id_alumne=$dada['lstalumne'][0]->id_alumne;
						
						//Destinatari
						$this->load->library('email', $config);
						$this->email->from($mail_tutor, $nom_tutor);
						$this->email->to($mail_alumne); 
						$this->email->subject($motiu);
						$this->email->message($missatge); 
						$this->email->set_newline("\r\n");
						if (!$this->email->send()){
							//Les dades de l'alumne sense enviament es guarden a un array.
							$array['alumnes'][0]=$id_alumne;
						}
						else{
							//Inserta nou status en status alumne
							$this->load->model('Alumnes_model');
							$this->Alumnes_model->setEstatAlumne($fila,$id_convocatoria,$eleccio);
							
						}
					}
				}// Fi de switch/case
			}

			//Si l'array no esta buit els correus no s'han enviat correctament. Surt un missatge
			if(!empty($array['alumnes'][0])){
				$string = implode(", ", $array['alumnes']);
				$this->session->set_flashdata('error', 'Els alumnes amb id: '.$string. ' han donat problemes');
			}
			//Si es dona el cas 10 llavors no redirecciona. Es dirigeix a la vista nou missatge
			if($redirect !='0'){		
				redirect('seguiment', 'refresh');
			}				
		}	
	}
}
?>