<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/**
 * Classe que representa el controlador d'usuaris.
 * @author David Español Diaz
 * @versió 1.0; PHP 5.0".
 */
class Usuaris extends CI_Controller{
	
	//Definició del constructor.
	public function __construct(){
		parent::__construct();
		//Carrega llibreries i helpers.
		$this->load->library('session');
		$this->load->helper('url');
		//Si no esta connectat no es pot visualitzar la plana.
		if(!$this->session->userdata('autenticacio')){
			$this->session->set_flashdata('error', 'No has fet login.');
			redirect('login', 'refresh');
		}
		//Carrega el model Usuaris.
		$this->load->model('Usuaris_model');
		$valor1=$this->uri->segment(2);
		$valor2=$this->uri->segment(3);		
	}
	
	/**
     * Mètode per carregar l'inici de la pàgina.
	 * Recull les dades a mostrar a la vista.
     */
	function index(){
	
		//Segons el rol d'usuari podrà veure uns continguts o altres.
		$rol=$this->session->userdata('rol_usuari');
		if($rol==2){
			redirect('inici', 'refresh');	
		}
		//Carrega llibreries i helpers.
		$this->load->helper('inicial');	
		
		//Carrega el llistat d'usuaris si hi ha.
		$dada['lstusuaris']=$this->Usuaris_model->llistat_usuaris();
		
		if($dada == -1){
			$dada['lstusuaris']='';
		}
		//Es carrega la vista.
		$this->load->view('usuaris_view', $dada);
	}
		
	/**
     * Mètode per inserir un nou usuari.
     * {pre: Hi ha dades al formulari rebut}.
     * {post: es crea un nou usuari cridant al model}.
     * Retorna missatges d'error si el formulari no es correcte.}
     */
	function nou_usuari(){
	
		//Segons el rol d'usuari podrà veure uns continguts o altres.
		$rol=$this->session->userdata('rol_usuari');
		if($rol==2){
			redirect('inici', 'refresh');	
		}
		
		//Carrega llibreries i helpers.
		$this->load->helper(array('url','form'));
		$this->load->library(array('form_validation','encrypt'));
		
		//Si les dades del formulari són correctes les recull. Si no, visualitza de nou el formulari.
		//Per mitjà de form_validation al directori /config comprova el formulari.
		if($this->form_validation->run('usuari')==FALSE){	 	
			$this->load->view('nou_usuari_view');
		} else{
			//Recull les dades del formulari.
			$id_usuari = $this->input->post("id_usuari");
			$nom_usuari = $this->input->post("nom_usuari");	
			$cognoms_usuari = $this->input->post("cognoms_usuari");			
			$password_usuari = $this->encrypt->sha1($this->input->post("password_usuari"));			
			$mail_usuari = $this->input->post("mail_usuari");
			$rol_usuari = $this->input->post("rol_usuari");
			
			//Crear objecte Usuari.				
			$obj_user=new Usuaris_model($id_usuari,$nom_usuari,$cognoms_usuari,$password_usuari,$mail_usuari,$rol_usuari);
			
			//Verifiquem que l'usuari no existeix
			if($obj_user->veureUsuari()==-1){
				$obj_user->nouUsuari();
				$dada['enllaç']='usuaris';
				//Es carrega la vista de confirmació.
				$this->load->view('formulari_validat',$dada);
			} else{
				//Aquest usuari ja existeix.
				$this->session->set_flashdata('error', 'Aquest usuari ja existeix.');
				$this->load->view('nou_usuari_view');
			}
		}		
	}
		
	/**
     * Mètode per modificar un alumne.
     * {pre: Hi ha dades al formulari rebut}.
     * {post: es modifica l'alumne cridant al model}.
     * Retorna missatges d'error si el formulari no es correcte.}
     */
	function modificar_usuari($id_usuari){
	
		//Segons el rol d'usuari podrà veure uns continguts o altres.
		$rol=$this->session->userdata('rol_usuari');
		if($rol==2){
			redirect('inici', 'refresh');	
		}
		
		//Carrega llibreries i helpers.
		$this->load->helper(array('url','form'));
		$this->load->library(array('form_validation','encrypt'));
		
		//Crear objecte usuari e insercio en un array.		
		$obj_user=new Usuaris_model($id_usuari);	
		$dada['lstusuaris']=$obj_user->veureUsuari();
		
		//Si les dades del formulari són correctes les recull. Si no visualitza de nou el formulari.
		//Per mitjà de form_validation al directori /config comprova el formulari.
		if($this->form_validation->run('usuari')==FALSE){	
			$this->load->view('modificar_usuari_view',$dada);
		} else{
			//Recull les dades del formulari.
			$id_usuari = $this->input->post("id_usuari");
			$nom_usuari = $this->input->post("nom_usuari");
			$cognoms_usuari = $this->input->post("cognoms_usuari");			
			$password_usuari = $this->input->post("password_usuari");		
			$mail_usuari = $this->input->post("mail_usuari");
			$rol_usuari = $this->input->post("rol_usuari");
	
			//Crear objecte Usuari
			$obj_user=new Usuaris_model($id_usuari,$nom_usuari,$cognoms_usuari,$password_usuari,$mail_usuari,$rol_usuari);
			$obj_user->modificarUsuari();	
						
			//Es carrega la vista de confirmació.			
			$dada['enllaç']='usuaris';
			$this->load->view('formulari_validat',$dada);		
		}		
	}
	
	/**
     * Mètode per a veure les propies dades d'usuari.
     * {pre: Hi ha dades al formulari rebut}.
     * {post: Es mostren les dades d'usuari cridant al model}.
     * Retorna missatges d'error si el formulari no es correcte.}
     */	
	function meves_dades(){
	
		//Carrega les dades de sessió, llibreries i helpers.
		$id_usuari = $this->session->userdata('id_usuari');
		$this->load->model('Usuaris_model');
		$this->load->helper(array('url','form'));
		$this->load->library(array('form_validation','encrypt'));
			
		//Crear objecte usuari e insercio en un array.	
		$obj_user=new Usuaris_model($id_usuari);
		
		//Obtenir dades de connexió al gestor de correu personal si hi ha.
		if($obj_user->veureSmtpUsuari()!=-1){
			$dada['usuari']=$obj_user->veureUsuari();
			$dada['smtp']=$obj_user->veureSmtpUsuari();
		} else{
			$dada['usuari']=$obj_user->veureUsuari();
			$dada['smtp'][0]->id_smtp='';
			$dada['smtp'][0]->password_smtp='';
		}
		
		//Si les dades del formulari són correctes les recull. Si no, visualitza de nou el formulari.	
		//Per mitjà de form_validation al directori /config comprova el formulari.
		if($this->form_validation->run('personals')==FALSE){		
			$this->load->view('meves_dades_view',$dada);
		} else{
			//Recull les dades del formulari.
			$password_usuari = $this->input->post("password_usuari");			
			$mail_usuari = $this->input->post("mail_usuari");
			$id_smtp = $this->input->post("id_smtp");				
			$password_smtp = $this->input->post("password_smtp");
						
			//Crida al mètode modificar Usuari-dades personals.			
			$dada['usuari']=$this->Usuaris_model->usuariModificarUsuari($id_usuari,$password_usuari,$mail_usuari,$id_smtp,$password_smtp);

			//Es carrega la vista de confirmació.			
			$dada['enllaç']='usuaris';
			$this->load->view('formulari_validat',$dada);			
		}		
	}
	
	/**
     * Mètode per esborrar un usuari.
     * {pre: Hi ha un usuari a esborrar}.
     * {post: L'usuari s'esborra cridant al model}.
     */	
	function esborrar_usuari($id_usuari){
	
		//Segons el rol d'usuari podrà veure uns continguts o altres.
		$rol=$this->session->userdata('rol_usuari');
		if($rol==2){
			redirect('inici', 'refresh');	
		}
		
		//Crear objecte usuari e insercio en un array.	
		$obj_user=new Usuaris_model($id_usuari);	
		$obj_user->esborrarUsuari();
		//Redirecció a la llista d'usuaris.
		redirect('usuaris', 'refresh');			
	}
}
?>