<?php
 /**
 * Classe que representa el model d'alumnes.
 * @author David Espaol Diaz.
 * @version 1.0; PHP 5.0".
 */
class alumnes_model extends CI_Model {

	private $taula_alumnes="alumnes";
	private $taula_estat_alumnes="estat_alumnes";
	private $id_alumne;
	private $nom;
	private $cognoms;
	private $mail;
	private $id_convocatoria;
	
	/**
     * Mtode constructor d'alumne. Crea un alumne.
     * {pre: Cap}
     * {post: retorna una instncia de la classe Alumne i carrega la base de dades.
     */
	public function __construct(){
		//Crida el Model constructor
		parent::__construct();
		$this->load->database();	   
		$args = func_get_args();
		$nargs = func_num_args();
		switch($nargs) {
			case 0:
				break;
			case 3:
				$this->id_alumne=$args[0];
				$this->id_convocatoria=$args[1];
				$this->mail=$args[2];	
				break;
			case 2:
				$this->id_alumne=$args[0];
				$this->id_convocatoria=$args[1];	
				break;
		} 
    }
	
	/**
     * Mtode per obtenir el nom de l'alumne.
     * @return nom - Nom de l'alumne.
     */
	public function getNomAlumne(){
		return $this->nom;
	}
	
	/**
     * Mtode per assignar el nom de l'alumne.
     * @param nom -Nom de l'alumne.
     */
	public function setNomAlumne($nom) {
        $this->nom = $nom;
    }
	
	/**
     * Mtode per obtenir el cognom de l'alumne.
     * @return cognoms - Cognoms de l'alumne.
     */
	public function getCognomsAlumne(){
		return $this->cognoms;
	}
	
	/**
     * Mtode per assignar el cognom de l'alumne.
     * @param cognoms - Cognoms de l'alumne.
     */
	public function setCognomsAlumne($cognoms) {
        $this->cognoms = $cognoms;
    }
	
	/**
     * Mtode per obtenir l'identificador de l'alumne.
     * @return id_alumne - Identificador de l'alumne.
     */
	public function getIdentificadorAlumne(){
		return $this->id_alumne;
	}
	
	/**
     * Mtode per assignar l'identificador de l'alumne.
     * @param id_alumne - Identificador de l'alumne.
     */
	public function setIdentificadorAlumne($id_alumne) {
        $this->id_alumne = $id_alumne;
    }
	
	/**
     * Mtode per obtenir el correu de l'alumne.
     * @return mail - Mail de l'alumne.
     */
	public function getCorreuAlumne(){
		return $this->mail;
	}
	
	/**
     * Mtode per assignar el correu de l'alumne.
     * @param mail - Mail de l'alumne.
     */
	public function setCorreuAlumne($mail) {
        $this->mail = $mail;
    }
	
	/**
     * Mtode per obtenir la convocatria de l'alumne.
     * @return id_convocatoria - Identificador de la convocatria.
     */
	public function getConvocatoriaAlumne(){
		return $this->id_convocatoria;
	}
	
	/**
     * Mtode per assignar una convocatria de l'alumne.
     * @param id_convocatoria - Identificador de la convocatria.
     */
	public function setConvocatoriaAlumne($id_convocatoria) {
        $this->id_convocatoria= $id_convocatoria;
    }
   
	/**
     * Mtode per obtenir la llista d'alumnes d'una convocatria.
     * @return Array - Llistat d'alumnes o -1 si no hi ha llistat.
     */
	public function llistat_alumnes($id_convocatoria){
		$this->db->where('id_convocatoria', $id_convocatoria);
		$query=$this->db->order_by("cognoms")->get($this->taula_alumnes);
		//Si s'han trobat valors a la BBDD es retornen, en cas contrari -1. 
        if ($query->num_rows>0){
            foreach ($query->result() as $fila){
                $dada[]=$fila;
            }
            return $dada;
        } else {
			$value=-1;
			$dada= array('id_alumne' => $value);
			return $dada;
		}
	}
   
	/**
     * Mtode que permet veure totes les dades d'un alumne a la base de dades.
     * {pre: La taula d'alumnes est creada a la base de dades}
     * {post: Es retorna un alumne.
     * @param Alumne a consultar.
     * @return dades de l'alumne.
     */
	public function veureAlumne(){	
		$this->db->where('id_convocatoria',$this->id_convocatoria);
		$this->db->where('id_alumne',$this->id_alumne);
		$query=$this->db->get($this->taula_alumnes);
		$dada=$query->result();
		return $dada;
	}
	
	/**
     * Mtode que permet modificar un alumne a la base de dades.
     * {pre: La taula d'alumnes est creada a la base de dades}
     * {post: Es modifica un alumne a la base de dades, si existeix}
     * @param Alumne a modificar.
     */
	public function modificarAlumne(){
		$this->load->library('session');
		$this->load->library('encrypt');
		$this->setAlumnes();
		$this->db->where('id_alumne', $this->getIdentificadorAlumne());
		$this->db->update($this->taula_alumnes);
	}	

	/**
     * Mtode com per fer les insercions i modificacions de dades d'alumnes a la BBDD.
     * {pre: La taula d'alumnes est creada a la base de dades}
     * {post: Es modifiquen les dades d'alumne a la base de dades}
     * @param  Alumne a modificar.
     */
	public function setAlumnes(){ 
		$dades = array(
               'mail' => $this->getCorreuAlumne(),
		);
		$this->db->set($dades);
	}
	
	/**
     * Mtode amb ds parmetres per obtenir la llista d'estats d'un alumne d'una convocatria.
	 * {pre: La taula d'alumnes i estats d'alumnes estan creades a la base de dades}
     * {post: Es retornen els estats}
     * @return Array - Llistat d'estats d'un alumne.
     */
	function llistatEstatsAlumnes($id_alumne,$id_convocatoria){	
		$this->db->select('data_estat,nom_estat');
		$this->db->from('estat_alumnes');	
		$this->db->where('id_convocatoria',$id_convocatoria); 
		$this->db->where('id_alumne', $id_alumne); 
		$this->db->join('estats', 'estat_alumnes.status_alumne = estats.status_alumne');
		$this->db->order_by("data_estat");
		$query=$this->db->get();

		//Si s'han trobat valors a la BBDD es retornen, en cas contrari -1. 
		if ($query->num_rows>0){
            foreach ($query->result() as $fila){
                $dada[]=$fila;
            }
            return $dada;
        } else{
			return -1;
		}		
   }
   
	/**
     * Mtode amb dos parmetres que permet veure el darrer estat d'un alumne a la base de dades.
     * {pre: La taula d'estat d'alumnes est creada a la base de dades}
     * {post: Es retorna el darrer estat de l'alumne o -1 si no hi ha.
     * @param $id_convocatoria,$id_alumne Alumne a consultar.
     * @return int - 1 o Array, darrer estat depenent de si l'alumne te estats.
     */
	public function obtenirDarrerEstatAlumne($id_alumne,$id_convocatoria){
		$this->db->select('status_alumne');
		$this->db->where('id_convocatoria', $id_convocatoria);
		$this->db->where('id_alumne', $id_alumne);
		$this->db->order_by("data_estat DESC");
		$this->db->limit(1);
		$query = $this->db->get($this->taula_estat_alumnes);
		$dada=$query->result();
		
		//Si s'han trobat valors a la BBDD es retornen, en cas contrari -1. 
		if ($query->num_rows>0){
			return $dada[0]->status_alumne; 
        } else{
			return -1;
		}
	}
	
	/**
     * Mtode amb dos parmetres que permet veure si s'ha enviat la benvinguda a alumne en la base de dades.
     * {pre: La taula estat d'alumnes est creada a la base de dades}
     * {post: Es retorna TRUE/FALSE}
     * @param $id_convocatria,$id_alumne Alumne a consultar.
     * @return TRUE/FALSE depenent de si s'ha donat la benvinguda a l'alumne.
     */
	public function obtenirBenvingudaAlumne($id_alumne,$id_convocatoria){	
		$this->db->select('status_alumne');
		$this->db->where('id_convocatoria', $id_convocatoria);
		$this->db->where('id_alumne', $id_alumne);
		$this->db->where('status_alumne', 2);
		$this->db->order_by("data_estat DESC");
		$this->db->limit(1);
		$query = $this->db->get($this->taula_estat_alumnes);
		
		// Retornar si la benvinguda s'ha enviat TRUE o no FALSE.
		if ($query->num_rows>0){
			return TRUE; 
        } else{	
			return FALSE;
		}
	}
	
	/**
     * Mtode amb dos parmetres que permet veure si s'ha establert una comunicaci personal amb l'alumne.
     * {pre: La taula d'estat alumnes est creada a la base de dades}
     * {post: Es retorna TRUE, FALSE}
     * @param $id_convocatria,$id_alumne Alumne a consultar.
     * @return 1/-1 depenent de si hi ha hagut feedback.
     */
	public function obtenirFeedback($id_alumne,$id_convocatoria){	
		$this->db->select('status_alumne');
		$this->db->where('id_convocatoria', $id_convocatoria);
		$this->db->where('id_alumne', $id_alumne);
		$this->db->where('status_alumne', 11);
		$this->db->order_by("data_estat DESC");
		$this->db->limit(1);
		
		// Retornar si hi ha hagut feedback o no.
		$query = $this->db->get($this->taula_estat_alumnes);
		if ($query->num_rows>0){
			return 1; 	
        } else{
			return -1;
		}
	}	
		
	/**
     * Mtode amb 3 parmetres que permet insertar una nou estat de l'alumne a la base de dades.
     * {pre: La taula d'estat d'alumnes est creada a la base de dades}
     * {post: Es defineix un nou estat de l'alumne}
     * @param $convocatria,$id_alumne,$status_alumne Estat a insertar.
     */	
	public function setEstatAlumne($id_alumne,$id_convocatoria,$status_alumne){
		$dada = array(
			   'id_alumne' => $id_alumne,
               'id_convocatoria' => $id_convocatoria,
               'status_alumne' => $status_alumne,
            );
		$this->db->insert($this->taula_estat_alumnes, $dada);
	}

	/**
     * Mtode que permet veure l'identificador d'un alumne a la base de dades.
     * {pre: La taula d'alumnes est creada a la base de dades}
     * {post: Es retorna un identificador.
     * @param mail a consultar.
     * @return Id de l'alumne.
     */
	public function veureId($mail_alumne){	
		$this->db->select('id_alumne');
		$this->db->where('mail',$mail_alumne);
		$query=$this->db->get($this->taula_alumnes);
		$dada=$query->result();
		return $dada[0]->id_alumne;

	}	
}
?>