<?php
 /**
 * Classe que representa el model de convocatoria
 * @author David Espaol Diaz
 * @versi 1.0; PHP 5.0".
 */
class convocatories_model extends CI_Model {
	
	private $taula_convocatories="convocatories";
	private $taula_estat_convocatories="estat_convocatories";
	private $taula_alumnes="alumnes";
	private $taula_estat_alumnes="estat_alumnes";
	private $nom_convocatoria;
	private $id_convocatoria;
	private $data_inici_convocatoria;
	private $data_fi_convocatoria;
	private $id_tutor;
	
	/**
     * Mtode constructor de Convocatria. Crea una convocatria.
     * {pre: Cap}
     * {post: retorna una instncia de la classe Convocatoria i carrega la base de dades.
     */
	public function __construct(){
		// Crida el Model constructor
		parent::__construct();
		$this->load->database();
		$args = func_get_args();
		$nargs = func_num_args();
		switch($nargs) {
			case 0:
				break;
			case 5:
				$this->id_convocatoria=$args[0];
				$this->nom_convocatoria=$args[1];
				$this->data_inici_convocatoria=$args[2];
				$this->data_fi_convocatoria=$args[3];
				$this->id_tutor=$args[4];
				break;
			case 1:
				$this->id_convocatoria=$args[0];
				break;
			case 2:
				$this->id_convocatoria=$args[0];
				$this->id_tutor=$args[1];
				break;
		}	
    }
	
	/**
     * Mtode per obtenir el nom de la convocatria.
     * @return nom_convocatoria - Nom de la convocatria.
     */
	public function getNomConvocatoria(){
		return $this->nom_convocatoria;
	}
	
	/**
     * Mtode per assignar el nom de la convocatria.
     * @param nom_convocatoria -Nom de la convocatria.
     */
	public function setNomConvocatoria($nom_convocatoria) {
        $this->nom_convocatoria = $nom_convocatoria;
    }
	
	/**
     * Mtode per obtenir l'identificador de la convocatria.
     * @return id_convocatoria - Identificador de la convocatria.
     */
	function getIdConvocatoria(){
		return $this->id_convocatoria;
	}
	
	/**
     * Mtode per assignar l'identificador de la convocatria.
     * @param id_convocatoria - Identificador de la convocatria.
     */
	public function setIdConvocatoria($id_convocatoria) {
        $this->id_convocatoria = $id_convocatoria;
    }
	
	/**
     * Mtode per obtenir la data d'inici de la convocatria.
     * @return data_inici_convocatoria - Data d'inici de la convocatria.
     */
	function getDataIniciConvocatoria(){
		return $this->data_inici_convocatoria;
	}
	
	/**
     * Mtode per assignar la data d'inici de la convocatria.
     * @param data_inici_convocatoria - Data d'inici de la convocatria.
     */
	public function setDataIniciConvocatoria($data_inici_convocatoria) {
        $this->data_inici_convocatoria= $data_inici_convocatoria;
    }
	
	/**
     * Mtode per obtenir la data de fi de la convocatria.
     * @return data_fi_convocatoria - Data de fi de la convocatria.
     */
	function getDataFiConvocatoria(){
		return $this->data_fi_convocatoria;
	}
	
	/**
     * Mtode per assignar la data de fi de la convocatria.
     * @param data_fi_convocatoria - Data de fi de la convocatria.
     */
	public function setDataFiConvocatoria($data_fi_convocatoria) {
        $this->data_fi_convocatoria= $data_fi_convocatoria;
    }
	
	/**
     * Mtode per obtenir el tutor de la convocatria.
     * @return id_tutor - Identificador del tutor de la convocatria.
     */
	function getIdTutor(){
		return $this->id_tutor;
	}
	
	/**
     * Mtode per assignar el tutor de la convocatria.
     * @param id_tutor - Tutor de la convocatria.
     */
	public function setIdTutor($id_tutor) {
        $this->id_tutor= $id_tutor;
    }
	
   
	/**
     * Mtode per obtenir la llista de convocatries d'un tutor.
     * @return Array - Llistat de convocatries.
     */
	public function llistat_convocatories($id_tutor){

		$this->db->select('*');
		$this->db->where('id_tutor', $id_tutor);
		$this->db->order_by("data_inici DESC");
		$query = $this->db->get($this->taula_convocatories);
		//Si s'han trobat valors a la BBDD es retornen, en cas contrari -1. 
        if ($query->num_rows>0){
			$new_array = array();
			$i = 0; 
            $result = $query->result();
            foreach ($result as $row){
				// Es posa en un array el llistat de totes les convocatries.
                $new_array[$i]= (object)array('id_convocatoria' => $row->id_convocatoria,
                     'nom_convocatoria' => $row->nom_convocatoria,
                     'data_inici'    => $row->data_inici,
					 'data_fi'    => $row->data_fi,
					 'status'   => $this->Convocatories_model->darrerEstatConvocatoria($row->id_convocatoria),
					 );
                
                ++$i;
			}
			return $new_array;
        } else {
			$value=-1;
			$dada= array('id_convocatoria' => $value);
			return $dada;
		}
   }
   
	/**
     * Mtode amb un parmetre que permet insertar una nova convocatria a la base de dades.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: es crea una nova convocatria en la base de dades}
     * @return TRUE/FALSE si s'ha creat la nova convocatria.
     */
	public function novaConvocatoria(){
		$this->setConvocatories();
		if($this->db->insert($this->taula_convocatories)){
			$return= true;
		} else{
			$return= false;
		}
		return $return;
	}
	
	/**
     * Mtode amb un parmetre que permet modificar una convocatria a la base de dades.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Es modifica una convocatria}
     */
    public function modificarConvocatoria(){
		$this->setConvocatories();
		$this->db->where('id_convocatoria', $this->getIdConvocatoria());
		$this->db->update($this->taula_convocatories);	
	}
   
	/**
     * Mtode com per fer les insercions i modificacions de convocatries a la BBDD amb un parmetre.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Es crea/modifica una convocatria a la base de dades}
     */
	public function setConvocatories(){ 
		$dades = array(
               'id_convocatoria' => $this->getIdConvocatoria(),
               'data_inici' => $this->getDataIniciConvocatoria(),
               'data_fi' => $this->getDataFiConvocatoria(),
			   'nom_convocatoria' =>$this->getNomConvocatoria(),
			   'id_tutor' =>$this->getIdTutor(),
		);
		$this->db->set($dades);
	}
   
	/**
     * Mtode amb 2 parmetres que permet insertar una nou estat de la convocatria a la base de dades.
     * {pre: La taula de estat convocatries est creada a la base de dades}
     * {post: Es defineix un nou estat de la convocatria}
     * @param $convocatria Convocatria a insertar, $estat Estat a insertar.
     */
	public function setEstatConvocatoria($convocatoria,$estat){
		$dades = array(
               'id_convocatoria' => $convocatoria,
               'status' => $estat,
        );
		$this->db->set($dades);
		$this->db->insert($this->taula_estat_convocatories);
	}
	
	/**
     * Mtode amb un parmetre que permet veure el darrer estat de la convocatria a la base de dades.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Es retorna el darrer estat de la convocatria.
     * 1 o 0 si depenent de si existeix o no}
     * @param $id_convocatria Convocatria a consultar.
     * @return Array de dades o FALSE depenent de si hi ha estat a la base de dades
     */
	public function darrerEstatConvocatoria($id_convocatoria){
		$this->db->select('status');
		$this->db->where('id_convocatoria', $id_convocatoria);
		$this->db->order_by("data_status DESC");
		$this->db->limit(1);
		$query = $this->db->get($this->taula_estat_convocatories);
		$dada=$query->result();

		//Si s'han trobat valors a la BBDD es retornen, en cas contrari retorna FALSE. 
		if ($query->num_rows>0){		
			return $dada[0]->status; 
        } else{
			return FALSE;
		}	
	}
	
	/**
     * Mtode amb un parmetre que permet veure si existeix la convocatria a la base de dades.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Es comprova que existeix la convocatria}
     * @return Array de dades.
     */
	public function existeixConvocatoria(){
		$this->db->where('id_convocatoria',$this->id_convocatoria);
		$query=$this->db->get($this->taula_convocatories);
		$dada=$query->result();
		return $dada;
	}
	
	/**
     * Mtode amb un parmetre que extreu dades d'una convocatria a la base de dades.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Es retorna la convocatria.}
     * @return Array de dades.
     */
	public function getConvocatoria(){
		$this->db->where('id_convocatoria',$this->id_convocatoria);
		$query=$this->db->get($this->taula_convocatories);
		$dada=$query->result();
		return $dada;		
	}
	
	/**
     * Mtode amb un parmetre que permet veure la convocatria actual del tutor.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Es retorna la convocatria actual del tutor o -1 si no t}
     * @param $id_tutor Tutor a consultar.
     * @return Array amb les dades o - 1 o 0 depenent de si hi ha convocatria.
     */
	public function veureConvocatoriaActual($id_tutor){
		$this->db->select('id_convocatoria');
		$this->db->where('id_tutor', $id_tutor);
		$this->db->where('data_inici <= CURDATE()');
		$this->db->where('data_fi >= CURDATE()');
		$query=$this->db->get($this->taula_convocatories);
		$dada=$query->result();
		//Si s'han trobat valors a la BBDD es retornen, en cas contrari -1. 
		if ($query->num_rows>0){		
			return $dada[0]->id_convocatoria; 
        } else{
			return -1;
		}	
	}
	
	/**
     * Mtode amb un parmetre que permet comprovar si s'han donat d'alta els alumnes.
     * {pre: La taula estat convocatries est creada a la base de dades}
     * {post: Es retorna si s'han donat d'alta.
     * @param $id_convocatria Convocatria a consultar.
     * @return int - 1 o 0 depenent de si estan donats d'alta.
     */
	public function verificarAlumnes($id_convocatoria){
	
		$this->db->select('status');
		$this->db->where('id_convocatoria', $id_convocatoria);
		$this->db->where('status', 1);
		$query=$this->db->get($this->taula_estat_convocatories);
		$data=$query->result();
		
		if ($query->num_rows>0){		
			return -1;
        }
		// No hi ha res 
		else{
			return 0;
		}
	}	
	
	/**
     * Mtode amb un parmetre que permet esborrar una convocatria.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: La convocatria s'ha esborrat}
     */
	public function esborrarConvocatoria(){
		$this->db->where('id_convocatoria', $this->id_convocatoria);
		$this->db->delete($this->taula_convocatories); 
		$this->db->where('id_convocatoria', $this->id_convocatoria);
		$this->db->delete($this->taula_estat_convocatories);
		$this->db->where('id_convocatoria', $this->id_convocatoria);
		$this->db->delete($this->taula_alumnes);
	}
   
	/**
     * Mtode amb 2 parmetres que permet associar un llistat d'alumnes a una convocatria.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Els alumnes s'han vinculat}
     * @param $id_convocatria Convocatria a associar, $fichero Fitxer excel amb les dades.
     * @return int - 1 o 0 depenent de si es superen els 80 alumnes al fitxer.
     */
	public function associarAlumnesConvocatoria($fichero,$id_convocatoria){
		//Es crida la llibreria Excel.
		require_once 'application/libraries/Spreadsheet/Excel/reader.php'; 
		$data = new Spreadsheet_Excel_Reader($fichero);  
		$data->read($fichero);  
		$nrows = $data->sheets[1]['numRows']; 
		$ncols = $data->sheets[1]['numCols'];
		$dades= Array();
		if($nrows >80){
			return -1;
		} else{
			for ($fila = 2; $fila <= $nrows; $fila++) {
				if(isset($data->sheets[1]['cells'][$fila][8])){
					$dades[$fila]['id_convocatoria'] = $id_convocatoria;
					$dades[$fila]['id_alumne'] = $data->sheets[1]['cells'][$fila][1];
					$dades[$fila]['nom'] = $data->sheets[1]['cells'][$fila][2];
					$dades[$fila]['cognoms'] = $data->sheets[1]['cells'][$fila][3];
					$dades[$fila]['mail'] = $data->sheets[1]['cells'][$fila][5];
					$this->db->insert('alumnes', $dades[$fila]);
						
					//Insertar estat 0 (donats d'alta)
					$estat[$fila]['id_convocatoria'] = $id_convocatoria;
					$estat[$fila]['id_alumne'] = $data->sheets[1]['cells'][$fila][1];
					$estat[$fila]['status_alumne'] = 1;
					$this->db->insert('estat_alumnes', $estat[$fila]);
				} else {
					break;
				}
			}
			return 0;
		}
	}
	
	/**
     * Mtode amb un parmetre que permet esborrar els alumnes d'una convocatria.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Els alumnes associats s'han esborrat}
     */
	function esborrarAlumnesConvocatoria(){
		$this->db->where('id_convocatoria', $this->id_convocatoria);
		$this->db->delete($this->taula_alumnes); 
	
		//S'esborren, a ms, tots els estats dels alumnes.
		$this->db->where('id_convocatoria', $this->id_convocatoria);
		$this->db->delete($this->taula_estat_alumnes);
		
		//S'esborrea l'estat alta alumnes convocatoria.
		$this->db->where('id_convocatoria', $this->id_convocatoria);
		$this->db->where('status', 1);
		$this->db->delete($this->taula_estat_convocatories);
	}
	
	/**
     * Mtode que permet comprovar que no es solapin en temps 2 convocatries.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Es retorna la comprovaci}
     * @return int - 1 si es solapen les dates.
     */
	function comprovarDates(){	
		$data1=$this->getDataIniciConvocatoria();
		$data2=$this->getDataFiConvocatoria();
		
		$q1="SELECT * from convocatories where id_convocatoria<>'".$this->getIdConvocatoria()."' AND id_tutor='".$this->getIdTutor()."' AND '".$data1."' BETWEEN data_inici AND data_fi";
		$q2="SELECT * from convocatories where id_convocatoria<>'".$this->getIdConvocatoria()."' AND id_tutor='".$this->getIdTutor()."' AND '".$data2."' BETWEEN data_inici AND data_fi";
		$query=mysql_query($q1);
		$query2=mysql_query($q2);
		
		if (mysql_fetch_row($query2)!=NULL || mysql_fetch_row($query)!=NULL){		
			return -1; 
        }
	}
}
?>