<?php
 /**
 * Classe que representa el model de la plana d'entrada.
 * Inclou dades estadstiques generals.
 * @author David Espaol Diaz
 * @version 1.0; PHP 5.0".
 */
class inici_model extends CI_Model {

	private $taula_convocatories="convocatories";
	private $taula_alumnes="alumnes";
	private $taula_estat_alumnes="estat_alumnes";
	private $id_convocatoria;
	private $estat_alumne;

	/**
     * Mtode constructor inici/estadistica. Crea una estadistica.
     * {pre: Cap}
     * {post: Retorna una instncia de la classe Estadstica i carrega la base de dades.
     */
	public function __construct(){
		// Crida el Model constructor
		parent::__construct();
		$this->load->database();	
		$args = func_get_args();
		$nargs = func_num_args();
		switch($nargs) {
			case 0:
				break;
			case 5:
				$this->id_convocatoria=$args[0];
				$this->estat_alumne=$args[1];
				break;
		}		
    }
	
	/**
     * Mtode que permet verificar si una convocatria est oberta.
     * {pre: La taula de convocatries est creada a la base de dades}
     * {post: Es retorna un Array si hi ha convocatoria oberta o -1 en cas contrari.
     * @param Convocatria a consultar.
     * @return Array de dades o -1 si no hi ha convocatria oberta.
     */
	function verificarIniciConvocatoria($obj_convocatoria){
		$this->db->where('data_fi >= CURDATE()');
		$this->db->where('data_inici <= CURDATE()');
		//$this->db->where('id_convocatoria', $obj_convocatoria->getIdConvocatoria());
		$this->db->where('id_tutor', $obj_convocatoria->getIdTutor());
		$query=$this->db->get($this->taula_convocatories);
		
		//Convocatria activa o no.
		if ($query->num_rows() > 0){
			// Es retorna la convocatoria.
			foreach ($query->result() as $fila){	
                $dada[]=$fila;
            }
		} else {
			$value=-1;
			$dada= array('id_convocatoria' => $value);
		}
		return $dada;
	}
	
	 /**
     * Mtode per obtenir el nombre total d'alumnes en un estat {2,3,4,9}
     * {pre: La taula d'estat alumnes est creada a la base de dades}
     * {post: Es retorna el nombre total d'alumnes amb l'estat indicat.
     * @param $obj_convocatoria Convocatoria a consultar.
	 * @param $estat estat
     * @return int-Nombre d'alumnes amb estat.
     */
	function obtenirInforme($obj_convocatoria,$estat){
		$this->db->distinct('id_alumne');
		$this->db->where('id_convocatoria', $obj_convocatoria->getIdConvocatoria());
		$this->db->where('status_alumne', $estat);
		$this->db->group_by('id_alumne'); 
		$query = $this->db->get($this->taula_estat_alumnes);	
		return $query->num_rows;
	} 
	
	/**
     * Mtode per obtenir el nombre total d'alumnes amb benvinguda
     * {pre: La taula d'estat alumnes est creada a la base de dades}
     * {post: Es retorna el nombre total d'alumnes amb l'estat indicat.
     * @param $obj_convocatoria Convocatoria a consultar.
     * @return int-Nombre d'alumnes amb estat.
     */
	function obtenirInformeBenvinguda($obj_convocatoria){
		$this->db->distinct('id_alumne');
		$this->db->where('id_convocatoria',$obj_convocatoria->getIdConvocatoria());
		$this->db->where('status_alumne', 1);
		$this->db->where('status_alumne <>', 2);
		$this->db->where('status_alumne <>', 3);
		$this->db->group_by('id_alumne'); 
		$query = $this->db->get($this->taula_estat_alumnes);
		return $query->num_rows;
	}
	
	/**
     * Mtode per obtenir el nombre total d'alumnes totals
     * {pre: La taula d'alumnes est creada a la base de dades}
     * {post: Es retorna el nombre total d'alumnes.
     * @param $obj_convocatoria Convocatoria a consultar.
     * @return int-Nombre d'alumnes totals.
     */
	function obtenirInformeAlumnesTotals($obj_convocatoria){
		$this->db->where('id_convocatoria',$obj_convocatoria->getIdConvocatoria());
		$query=$this->db->count_all_results($this->taula_alumnes);
		return $query;	
	}
	
	/**
     * Mtode per obtenir el nombre total d'alumnes no contactats.
     * {pre: La taula d'estat alumnes/alumnes est creada a la base de dades}
     * {post: Es retorna el nombre total d'alumnes no contactats.
     * @param $obj_convocatoria Convocatoria a consultar.
     * @return int-Nombre d'alumnes no contactats.
     */
	function obtenirInformeAlumnesNoContactats($obj_convocatoria){

		$this->db->distinct('estat_alumnes.id_alumne');
		$estats = array(5,6,7,8,9,10,11);
		
		$this->db->where_in('status_alumne', $estats);
		$this->db->join('estat_alumnes', 'alumnes.id_alumne = estat_alumnes.id_alumne');
		$this->db->where('alumnes.id_convocatoria',$obj_convocatoria->getIdConvocatoria());
		$query = $this->db->get($this->taula_alumnes);
		return $query->num_rows;

	}
}
?>