<?php
 /**
 * Classe que representa el model de login.
 * @author David Espaol Diaz.
 * @version 1.0; PHP 5.0".
 */
class login_model extends CI_Model {

	private $taula_usuaris="usuaris";
	private $id_usuari;
	private $password;
	private $id_convocatoria;
	
	/**
     * Mtode constructor de login. Crea una connexi.
     * {pre: No hi ha una connexi oberta}
     * {post: retorna una instncia de la classe Connexi i carrega la base de dades.
     */
	public function __construct() {
		// Crida el Model constructor
		parent::__construct();
		$this->load->database();
	   
		$args = func_get_args();
		$nargs = func_num_args();
		switch($nargs) {
			case 0:
				break;
			case 2:
				$this->id_usuari=$args[0];
				$this->password=$args[1];
				break;
		}  
    }
	
	/**
     * Mtode per obtenir el password de l'usuari.
     * @return id_password - Password de l'usuari.
     */
	function getPassword(){
		return $this->password;
	}
	
	/**
     * Mtode per assignar el password de l'usuari.
     * @param password - Password de l'usuari.
     */
	public function setPassword($password) {
        $this->password = $password;
    }
	
	/**
     * Mtode per obtenir l'identificador de l'usuari.
     * @return id_usuari - Nom de l'usuari.
     */
	function getIdentificadorUsuari(){
		return $this->id_usuari;
	}
	
	/**
     * Mtode per assignar l'identificador de l'usuari.
     * @param id_usuari - Identificador de l'usuari.
     */
	public function setIdentificadorUsuari($id_usuari) {
        $this->id_usuari = $id_usuari;
    }
	
	/**
     * Mtode per obtenir l'identificador de la convocatria.
     * @return id_convocatoria - Identificador de la convocatria.
     */
	function getIdConvocatoria(){
		return $this->id_convocatoria;
	}
	
	/**
     * Mtode per assignar l'identificador de la convocatria.
     * @param id_convocatoria - Identificador de la convocatria.
     */
	public function setIdConvocatoria($id_convocatoria) {
        $this->id_convocatoria = $id_convocatoria;
    }

	/**
     * Mtode per autenticar un usuari.
     * {pre: La taula d'usuaris est creada a la base de dades}
     * {post: Es retornen dades d'usuari o -1}
     * @return Array dades o -1 depenent de si les dades sn correctes o no.
     */
	function autenticarUsuari(){	
		$this->db->select('nom_usuari');
		$this->db->where('id_usuari',$this->id_usuari);
		$this->db->where('password',$this->password);
		$query=$this->db->get($this->taula_usuaris);
		$dada=$query->result();
		
		// Si les dades de la consulta existeixen es retornen dades. En cas contrari -1.
		if ($query->num_rows() > 0){
			return $dada;	
		} else {
			$dada=-1;
			return $dada;
		}
	}
	
	/**
     * Mtode que fa que el sistema introdueixi un nou password generat automaticament.
     * {pre: La taula d'usuaris est creada a la base de dades}
     * {post: El password s'ha modificat}
     * @param $password,$id_usuari a consultar.
     */
	 
	public function nouPassword($password,$id_usuari){	
		$password_encrypt= $this->encrypt->sha1($password);
		$dades = array('password' => $password_encrypt);
		$this->db->where('id_usuari', $id_usuari);
		$this->db->update($this->taula_usuaris,$dades);
	}
}
?>