<?php
 /**
 * Classe que representa el model de convcatòries.
 * @author David Español Diaz.
 * @versió 1.0; PHP 5.0".
 */
class usuaris_model extends CI_Model {

	private $taula_usuaris="usuaris";
	private $taula_gestor="gestor_correu";
	private $taula_estat_alumnes="estat_alumnes";
	private $taula_rols="rols";
	private $taula_convocatories="convocatories";
	private $id_usuari;
	private $nom_usuari;
	private $cognoms_usuari;
	private $mail_usuari;
	private $password_usuari;
	private $rol_usuari;
	private $id_smtp;
	private $password_smtp;
	
	/**
     * Mètode constructor de convocatòria. Crea una convocatòria.
     * {pre: Cap}
     * {post: retorna una instància de la classe Convocatòria i carrega la base de dades.
     */
	public function __construct() {
		//Crida el Model constructor
		parent::__construct();
		$this->load->database();
		$args = func_get_args();
		$nargs = func_num_args();
		switch($nargs) {
			case 0:
				break;
			case 1:
				$this->id_usuari=$args[0];
				break;
			case 6:
				$this->id_usuari=$args[0];
				$this->nom_usuari=$args[1];
				$this->cognoms_usuari=$args[2];	
				$this->password_usuari=$args[3];
				$this->mail_usuari=$args[4];
				$this->rol_usuari=$args[5];
				break;
			case 3:
				$this->id_usuari=$args[0];
				$this->id_smtp=$args[1];
				$this->password_smtp=$args[2];
				break;
		}
    }
	
	/**
     * Mètode per obtenir el nom de l'usuari.
     * @return nom_usuari - Nom de l'usuari.
     */
	function getNomUsuari(){
		return $this->nom_usuari;
	}
	
	/**
     * Mètode per assignar el nom de l'usuari.
     * @param nom_usuari -Nom de l'usuari.
     */
	public function setNomUsuari($nom) {
        $this->nom_usuari = $nom_usuari;
    }
	
	/**
     * Mètode per obtenir el cognom de l'usuari.
     * @return cognoms_usuari - Cognoms de l'usuari.
     */
	function getCognomsUsuari(){
		return $this->cognoms_usuari;
	}
	
	/**
     * Mètode per assignar els cognoms de l'usuari.
     * @param cognoms_usuari - Cognoms de l'usuari.
     */
	public function setCognomsUsuari($cognoms_usuari) {
        $this->cognoms_usuari = $cognoms_usuari;
    }
	
	/**
     * Mètode per obtenir l'identificador de l'usuari.
     * @return id_usuari - Identificador de l'usuari.
     */
	function getIdUsuari(){
		return $this->id_usuari;
	}
	
	/**
     * Mètode per assignar l'identificador de l'usuari.
     * @param id_usuari - Identificador de l'usuari.
     */
	public function setIdUsuari($id_usuari) {
        $this->id_usuari = $id_usuari;
    }
	
	/**
     * Mètode per obtenir el correu de l'usuari.
     * @return mail_usuari - Mail de l'usuari.
     */
	function getMailUsuari(){
		return $this->mail_usuari;
	}
	
	/**
     * Mètode per assignar el correu de l'usuari.
     * @param mail_usuari - Mail de l'usuari.
     */
	public function setMailUsuari($mail_usuari) {
        $this->mail_usuari = $mail_usuari;
    }
	
	/**
     * Mètode per obtenir el password de l'usuari.
     * @return password_usuari - Password de l'usuari.
     */
	function getPasswordUsuari(){
		return $this->password_usuari;
	}
	
	/**
     * Mètode per assignar el password de l'usuari.
     * @param password_usuari - Password de l'usuari.
     */
	public function setPasswordUsuari($password_usuari) {
        $this->password_usuari= $password_usuari;
    }
	
	/**
     * Mètode per obtenir el rol de l'usuari.
     * @return rol_usuari - Rol de l'usuari.
     */
	function getRolUsuari(){
		return $this->rol_usuari;
	}
	
	/**
     * Mètode per assignar el rol de l'usuari.
     * @param rol_usuari - Rol de l'usuari.
     */
	public function setRolUsuari($rol_usuari) {
        $this->rol_usuari= $rol_usuari;
    }
	
	/**
     * Mètode per obtenir el id smtp de l'usuari.
     * @return id_smtp - Id Smtp de l'usuari.
     */
	function getIdSmtp(){
		return $this->id_smtp;
	}
	
	/**
     * Mètode per assignar el id smtp de l'usuari.
     * @param id_smtp - Id Smtp de l'usuari.
     */
	public function setIdSmtp($id_smtp) {
        $this->id_smtp= $id_smtp;
    }
	/**
     * Mètode per obtenir el password smtp de l'usuari.
     * @return password_smtp - Password Smtp de l'usuari.
     */
	function getPasswordSmtp(){
		return $this->password_smtp;
	}
	
	/**
     * Mètode per assignar el password smtp de l'usuari.
     * @param password_smtp - Password Smtp de l'usuari.
     */
	public function setPaswordSmtp($password_smtp) {
        $this->password_smtp= $password_smtp;
    }
	
	/**
     * Mètode per obtenir la llista d'usuaris.
     * @return Array - Llistat d'usuaris.
     */
	function llistat_usuaris(){
		$this->db->select('id_usuari,nom_usuari,cognoms_usuari,mail_usuari,rol');
		$query=$this->db->order_by("cognoms_usuari")->get($this->taula_usuaris);
		//Si s'han trobat valors a la BBDD es retornen, en cas contrari -1. 
		if ($query->num_rows>0){
			$new_array = array();
			$i = 0; 
            $result = $query->result();
            foreach ($result as $row){	
				// Set noves variables a l'array.
                $new_array[$i]= (object)array('id_usuari' => $row->id_usuari,
                     'nom_usuari' => $row->nom_usuari,
                     'cognoms_usuari'    => $row->cognoms_usuari,
					 'mail_usuari'    => $row->mail_usuari,
					 'rol'   => $this->Usuaris_model->veureRolUsuari($row->rol),
					 ); 
                ++$i; 
			}
			return $new_array;
        } else {
			$value=-1;
			$data= array('id_usuari' => $value);
			return $data;
		}	
	}
	
	/**
     * Mètode amb un paràmetre que permet insertar una nou usuari a la base de dades.
     * {pre: La taula d'usuaris està creada a la base de dades}
     * {post: Es crea un nou usuari a la base de dades si no existeix}
     */
    function nouUsuari(){
		$this->setUsuaris();
		$this->db->insert($this->taula_usuaris);
		$dada_gestor=array('id_usuari' => $this->getIdUsuari());
		$this->db->insert($this->taula_gestor,$dada_gestor);
	}
	
	/**
     * Mètode que permet modificar un usuari a la base de dades.
     * {pre: La taula d'usuaris està creada a la base de dades}
     * {post: Es modifica un usuari a la base de dades si existeix}
     */
	function modificarUsuari(){	
		$this->load->library('session');
		$this->load->library('encrypt');
		$this->setUsuaris();			
		$this->db->where('id_usuari', $this->getIdUsuari());
		$this->db->update($this->taula_usuaris);
	
	}
	
	/**
     * Mètode comú per fer les insercions i modificacions d'usuaris a la BBDD.
     * {pre: La taula d'usuaris està creada a la base de dades}
     * {post: Es crea una nou usuari a la base de dades si no existeix i retorna
     */
	public function setUsuaris(){ 
		$password=$this->getPasswordUsuari();
		$dades = array(
				   'id_usuari' => $this->getIdUsuari(),
				   'nom_usuari' => $this->getNomUsuari(),
				   'cognoms_usuari' => $this->getCognomsUsuari(),
				   'mail_usuari' => $this->getMailUsuari(),
				   'rol' => $this->getRolUsuari()
		);	
		// Si es detecta que també es vol canviar el password.
		if (!empty($password)) {
			$dades['password'] = $password;	
		}
		$this->db->set($dades);
	}
	
	/**
     * Mètode que permet veure si existeix l'usuari a la base de dades.
     * {pre: La taula d'usuaris està creada a la base de dades}
     * {post: Es retorna l'usuari o -1}
     * @return Array o  - 1 depenent de si l'usuari ja existeix a la base de dades
     */
	public function veureUsuari(){
		$this->db->where('id_usuari',$this->getIdUsuari());
		$query=$this->db->get($this->taula_usuaris);
		$dada=$query->result();
		// Si les dades de la consulta existeixen.
		if ($query->num_rows() > 0){
			// Es retornen les dades.
			return $dada;	
		} else {
			$dada=-1;
			// Es retorna -1 com a fals
			return $dada;
		}
	}
	
	/**
     * Mètode que permet veure les dades de connexió d'usuari a un compte de correu.
     * {pre: La taula de gestió de correu està creada a la base de dades}
     * {post: Es retornen les dades o -1 si no hi ha dades}
     * @return Array de dades o - 1 depenent de si l'usuari te dades de compte de correu.
     */
	public function veureSmtpUsuari(){
		$this->db->select('id_smtp,password_smtp');
		//echo $this->id_usuari;
		$this->db->where('id_usuari',$this->id_usuari);
		$this->db->where('id_smtp !=', '');
		$this->db->where('password_smtp !=', '');
		$query=$this->db->get($this->taula_gestor);
		$data=$query->result();
		// Si les dades de la consulta existeixen.
		if ($query->num_rows() > 0){
			// Es retornen les dades.
			return $data;	
		} else {
			$data=-1;
			// Es retorna -1 com a fals
			return $data;
		}
	}
		
	/**
     * Mètode que permet l'usuari introduir les dades de connexió a un compte de correu electrónic.
     * {pre: La taula d'usuaris està creada a la base de dades}
     * {post: Les dades s'han guardat}
     * @param $id_usuari
	 * @param $password_usuari
	 * @param $mail_usuari
	 * @param $id_smtp
	 * @param $password_smtp
     */
	public function usuariModificarUsuari($id_usuari,$password_usuari,$mail_usuari,$id_smtp,$password_smtp){
		//Es carreguen les llibreries d'encriptació.
		$this->load->library('session');
		$this->load->library('encrypt');
		
		//Comprova quines dades s'han de guardar i comprovar les confirmacions de cadascuna.
		if (!empty($password_usuari)) {
			$password_encrypt= $this->encrypt->sha1($password_usuari);
			$dades=array('password' => $password_encrypt,'mail_usuari' => $mail_usuari);
			$this->db->where('id_usuari', $id_usuari);
			$this->db->update($this->taula_usuaris,$dades);
		}
		else{ 
			$dades=array('mail_usuari' => $mail_usuari);
			$this->db->where('id_usuari', $id_usuari);
			$this->db->update($this->taula_usuaris,$dades);
		}	
		if (!empty($password_smtp)) {
			$password_encrypt_smtp= $this->encrypt->encode($password_smtp);	
			$dades=array('id_smtp' => $id_smtp, 'password_smtp' => $password_encrypt_smtp);
			$this->db->where('id_usuari', $id_usuari);
			$this->db->update($this->taula_gestor,$dades);
		}	
		else{ 
			$dades=array('id_smtp' => $id_smtp);	
			$this->db->where('id_usuari', $id_usuari);
			$this->db->update($this->taula_gestor,$dades);
		}
	}
		
	/**
     * Mètode amb un paràmetre que permet esborrar un usuari.
     * {pre: La taula d'usuaris està creada a la base de dades}
     * {post: L'usuari s'ha esborrat}
     */
	public function esborrarUsuari(){	
		$this->db->where('id_usuari',$this->id_usuari);
		$this->db->delete($this->taula_usuaris); 
	
		//S'esborren les dades del gestor de correu.
		$this->db->where('id_usuari',$this->id_usuari);
		$this->db->delete($this->taula_gestor);
		
		//S'esborren totes les convocatories associades  a l'usuari.
		//Permet que un nou usuari doni d'alta de nou la convocatòria.
		$this->db->where('id_tutor',$this->id_usuari);
		$this->db->delete($this->taula_convocatories);
	}
	
	/**
     * Mètode amb un paràmetre que permet veure el rol en format text d'un usuari
     * {pre: La taula de rols està creada a la base de dades}
     * {post: Es mostra el rol d'usuari}
     * @param $rol Rol a veure.
     * @return String.
     */	
	public function veureRolUsuari($rol){
		
		$this->db->select('nom_rol');
		$this->db->where('rol',$rol);
		$query=$this->db->get($this->taula_rols);
		$data=$query->result();
		return $data[0]->nom_rol;

	}
}
?>